% integrate hycom frequency bands

% hycom_ke('0')
% hycom_ke('15')

function hycom_ke(depth_level)

    addpath('/huron/jbrasch/jlab')
    jlab_addpath

    dir = '/huron/jbrasch/hycom/results/';
    ke_file = ['/huron/jbrasch/ke_results/ke_hycom_' depth_level 'm.mat'];
    spec_file = [dir 'spectra_' depth_level 'm.nc'];

    norm_constant=1440*(1/24)/539.625;
    ke_uv = ncread(spec_file, 'ke_uv') * norm_constant;
    X = ncread(spec_file, 'X');
    Y = ncread(spec_file, 'Y');

    plat = ncread(spec_file, 'lat');
    plon = ncread(spec_file, 'lon');

    freq_cpd = ncread(spec_file, 'freq_time') * 86400;

    % --- remove shallow ocean ---
    
    total_ke_file = [dir 'total_ke_hycom_' depth_level 'm.nc'];
    total_ke = ncread(total_ke_file, '__xarray_dataarray_variable__');

    load('/huron/jbrasch/hycom/grid/topo.mat', 'depth')
    depth = depth(X, Y);

    ke_uv(depth < 500) = NaN;
    total_ke(depth < 500) = NaN;

    % --- integrate over frequency bands ---

    near_inertial = NaN(length(X), length(Y));
    semidiurnal = NaN(length(X), length(Y));
    diurnal = NaN(length(X), length(Y));
    highf = NaN(length(X), length(Y));

    near_inertial_wide = NaN(length(X), length(Y));
    semi_wide = NaN(length(X), length(Y));

    for x = 1:length(X)
        for y = 1:length(Y)

            if ~isnan(ke_uv(x,y,1))

                % spectrum at point
                spec = squeeze(ke_uv(x, y, :));

                % lat at point
                curr_lat = plat(x, y);

                % integrate
                [near_inertial_counter, semi_counter, diurnal_counter, high_counter] = ke_integrate(freq_cpd(freq_cpd>=0), spec(freq_cpd>=0), curr_lat);
                [near_inertial_cwise, semi_cwise, diurnal_cwise, high_cwise] = ke_integrate(-freq_cpd(freq_cpd<0), spec(freq_cpd<0), curr_lat);

                % save
                near_inertial(x, y) = near_inertial_counter+near_inertial_cwise;
                semidiurnal(x, y) = semi_counter+semi_cwise;
                diurnal(x, y) = diurnal_counter+diurnal_cwise;
                highf(x, y) = high_counter+high_cwise;

                [near_inertial_wide_counter, semi_wide_counter] = ke_integrate_wide(freq_cpd(freq_cpd>=0), spec(freq_cpd>=0), curr_lat);
                [near_inertial_wide_wise, semi_wide_cwise] = ke_integrate_wide(-freq_cpd(freq_cpd<0), spec(freq_cpd<0), curr_lat);

                near_inertial_wide(x, y) = near_inertial_wide_counter+near_inertial_wide_wise;
                semi_wide(x, y) = semi_wide_counter+semi_wide_cwise;

            end
        end
    end

    % --- low frequency ---

    lowf = total_ke - highf;

    save(ke_file, 'highf', 'near_inertial', 'semidiurnal', 'diurnal', 'lowf', 'near_inertial_wide', 'semi_wide', '-v7.3')

    % --- bin average ---

    % from Jay
    icnt = 0;
    for i = 74:360+74
        icnt = icnt+1;
        jcnt = 0;
        for j = -80:80
            jcnt = jcnt+1;
            loni(icnt,jcnt) = i;
            lati(icnt,jcnt) = j;
        end
    end

    lat = lati(1,:);
    lon = loni(:, 1);

    near_inertial_bin = twodstats(plat, plon, near_inertial, lat, lon);
    semi_bin = twodstats(plat, plon, semidiurnal, lat, lon);
    diurnal_bin = twodstats(plat, plon, diurnal, lat, lon);
    lowf_bin = twodstats(plat, plon, lowf, lat, lon);

    near_inertial_wide_bin = twodstats(plat, plon, near_inertial_wide, lat, lon);
    semi_wide_bin = twodstats(plat, plon, semi_wide, lat, lon);
    
    lat_grid = twodstats(plat, plon, plat, lat, lon);
    lon_grid = twodstats(plat, plon, plon, lat, lon);

    lat = lat(1:length(lat)-1);
    lon = lon(1:length(lon)-1);

    % --- zonal average ---

    near_inertial_avg = zeros(length(lat), 1);
    semi_avg = zeros(length(lat), 1);
    diurnal_avg = zeros(length(lat), 1);
    lowf_avg = zeros(length(lat), 1);

    semi_wide_avg = zeros(length(lat), 1);
    near_inertial_wide_avg = zeros(length(lat), 1);

    for i = 1:length(lat)

        near_inertial_avg(i) = nanmean(near_inertial_bin(:, i));
        semi_avg(i) = nanmean(semi_bin(:, i));
        diurnal_avg(i) = nanmean(diurnal_bin(:, i));
        lowf_avg(i) = nanmean(lowf_bin(:, i));

        semi_wide_avg(i) = nanmean(semi_wide_bin(:, i));
        near_inertial_wide_avg(i) = nanmean(near_inertial_wide_bin(:, i));

    end

    save(ke_file, 'lat', 'lon', 'near_inertial_avg', 'semi_avg', 'diurnal_avg', 'lowf_avg', 'semi_wide_avg', 'near_inertial_wide_avg', '-append')

%     lat_grid = lati(1:length(lon), 1:length(lat));
%     lon_grid = loni(1:length(lon), 1:length(lat));

    near_inertial_bin = hycom_shift_grid(near_inertial_bin);
    semi_bin = hycom_shift_grid(semi_bin);
    diurnal_bin = hycom_shift_grid(diurnal_bin);
    lowf_bin = hycom_shift_grid(lowf_bin);

    near_inertial_wide_bin = hycom_shift_grid(near_inertial_wide_bin);
    semi_wide_bin = hycom_shift_grid(semi_wide_bin);

    lon_grid = lon_grid - 74;

    save(ke_file, 'lat_grid', 'lon_grid', 'near_inertial_bin', 'semi_bin', 'diurnal_bin', 'lowf_bin', 'near_inertial_wide_bin', 'semi_wide_bin', '-append')

end
