% isolate frequency bands, integrate the resulting spectrum

function [near_intertial, semidiurnal, diurnal, high] = ke_integrate(freq, spec, lat)

    % lat -> cor
    cor = 4 * pi * sind(abs(lat)) / 86164; % units rad/s
    cor = cor * 86400 / 2 / pi; % units cpd

    % ----- NEAR INERTIAL KE -----
    spec_near_inertial = spec;

	near_inertial_min = cor * .9; % in cpd
	near_inertial_max = cor * 1.1;

    spec_near_inertial(freq < near_inertial_min) = 0;
    spec_near_inertial(freq > near_inertial_max) = 0;

    near_intertial = abs(trapz(freq, spec_near_inertial));

    % ----- SEMI-DIURNAL KE -----
    spec_semidiurnal = spec;

	semidiurnal_min = 1.9; % in cpd
	semidiurnal_max = 2.1;

    spec_semidiurnal(freq < semidiurnal_min) = 0;
    spec_semidiurnal(freq > semidiurnal_max) = 0;

    semidiurnal = abs(trapz(freq, spec_semidiurnal));

    % ----- DIURNAL KE -----
    spec_diurnal = spec;

	diurnal_min = .9; % in cpd
	diurnal_max = 1.1; 

    spec_diurnal(freq < diurnal_min) = 0;
    spec_diurnal(freq > diurnal_max) = 0;

    diurnal = abs(trapz(freq, spec_diurnal));

    % ----- HIGH KE -----
    spec_high = spec;

    spec_high(freq < 0.5) = 0;

    high = abs(trapz(freq, spec_high));
    
end
