% mitgcm_ke

% mitgcm_ke('0')
% mitgcm_ke('15')

function mitgcm_ke(depth_level)

    addpath('/huron/jbrasch/jlab')
    jlab_addpath

    res_dir = '/huron/jbrasch/mitgcm/results/';
    ke_file = ['/huron/jbrasch/ke_results/ke_llc4320_' depth_level 'm.mat'];
    spec_file = [res_dir 'spectra_' depth_level 'm.nc'];

    norm_constant=1440*(1/24)/539.625;
    ke_uv = ncread(spec_file, 'ke_uv') * norm_constant;
    X = ncread(spec_file, 'i');
    Y = ncread(spec_file, 'j');
    
    grid_dir = '/huron/jbrasch/mitgcm/grid/';

    YC = ncread([grid_dir 'YC.nc'], 'YC'); % lat grid
    XC = ncread([grid_dir 'XC.nc'], 'XC'); % lon grid

    freq_cpd = ncread(spec_file, 'freq_time') * 86400;

    % --- remove shallow ocean (< 500m) ---

    depth = ncread([grid_dir 'Depth.nc'] , 'Depth');
    ke_uv(depth < 500) = NaN;
    
    % --- integrate over frequency bands ---

    diurnal = NaN(1440, 1080);
    semidiurnal = NaN(1440, 1080);
    near_inertial = NaN(1440, 1080);
    highf = NaN(1440, 1080);

    for x = 1:length(X)
        for y = 1:length(Y)

            if ~isnan(ke_uv(x,y,1))

                % spectrum at point
                spec = squeeze(ke_uv(x, y, :));

                % lat at point
                curr_lat = YC(x, y);

                % integrate
                [near_inertial_counter, semi_counter, diurnal_counter, high_counter] = ke_integrate(freq_cpd(freq_cpd>=0), spec(freq_cpd>=0), curr_lat);
                [near_inertial_cwise, semi_cwise, diurnal_cwise, high_cwise] = ke_integrate(-freq_cpd(freq_cpd<0), spec(freq_cpd<0), curr_lat);

                % save
                near_inertial(x, y) = near_inertial_counter+near_inertial_cwise;
                semidiurnal(x, y) = semi_counter+semi_cwise;
                diurnal(x, y) = diurnal_counter+diurnal_cwise;
                highf(x, y) = high_counter+high_cwise;
            end

        end
    end

    % --- low frequency ---
    
    total_ke_file = [res_dir 'total_ke_' depth_level 'm.nc'];
    total_ke = ncread(total_ke_file, '__xarray_dataarray_variable__');
    total_ke(depth < 500) = NaN;

    lowf = total_ke - highf;

    save(ke_file, 'highf', 'near_inertial', 'semidiurnal', 'diurnal', 'lowf', '-v7.3')

    % --- bin average ---

    lat = -90:72;
    lon = -180:180;

    near_inertial_bin = twodstats(YC, XC, near_inertial, lat, lon);
    semi_bin = twodstats(YC, XC, semidiurnal, lat, lon);
    diurnal_bin = twodstats(YC, XC, diurnal, lat, lon);
    lowf_bin = twodstats(YC, XC, lowf, lat, lon);

    lat_grid = twodstats(YC, XC, YC, lat, lon);
    lon_grid = twodstats(YC, XC, XC, lat, lon);

    lat = lat(1:length(lat)-1);
    lon = lon(1:length(lon)-1);

    near_inertial_avg = zeros(length(lat), 1);
    semi_avg = zeros(length(lat), 1);
    diurnal_avg = zeros(length(lat), 1);
    lowf_avg = zeros(length(lat), 1);

    for i = 1:length(lat)

        near_inertial_avg(i) = nanmean(near_inertial_bin(:, i));
        semi_avg(i) = nanmean(semi_bin(:, i));
        diurnal_avg(i) = nanmean(diurnal_bin(:, i));
        lowf_avg(i) = nanmean(lowf_bin(:, i));
    
    end

    save(ke_file, 'lat', 'lon', 'near_inertial_avg', 'semi_avg', 'diurnal_avg', 'lowf_avg', '-append')

    near_inertial_bin = mitgcm_shift_grid(near_inertial_bin);
    semi_bin = mitgcm_shift_grid(semi_bin);
    diurnal_bin = mitgcm_shift_grid(diurnal_bin);
    lowf_bin = mitgcm_shift_grid(lowf_bin);
    lon_grid = lon_grid + 180;

    save(ke_file, 'lat_grid', 'lon_grid', 'near_inertial_bin', 'semi_bin', 'diurnal_bin', 'lowf_bin', '-append')
